==> apo-ws-client-6.00.10.3-sources.jar: fr/univlorraine/apowsclient/laissezPasser/MettreAJourLaissezPasserWSV2.java <==

package fr.univlorraine.apowsclient.laissezPasser;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="_typLpa" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="_codAnu" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="_numOPI" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="_codEtu" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="_codEtp" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="_codVrsVet" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="_codDip" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="_codVrsVdi" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="_codRgi" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="_codStu" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="_libCmtLpa" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="_codCatOuiSi" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="_mtfCat" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="_codCatExoExt" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "typLpa",
    "codAnu",
    "numOPI",
    "codEtu",
    "codEtp",
    "codVrsVet",
    "codDip",
    "codVrsVdi",
    "codRgi",
    "codStu",
    "libCmtLpa",
    "codCatOuiSi",
    "mtfCat",
    "codCatExoExt"
})
@XmlRootElement(name = "mettreAJourLaissezPasserWS_V2")
public class MettreAJourLaissezPasserWSV2 {

    @XmlElement(name = "_typLpa", required = true)
    protected String typLpa;
    @XmlElement(name = "_codAnu", required = true)
    protected String codAnu;
    @XmlElement(name = "_numOPI", required = true)
    protected String numOPI;
    @XmlElement(name = "_codEtu", required = true)
    protected String codEtu;
    @XmlElement(name = "_codEtp", required = true)
    protected String codEtp;
    @XmlElement(name = "_codVrsVet", required = true)
    protected String codVrsVet;
    @XmlElement(name = "_codDip", required = true)
    protected String codDip;
    @XmlElement(name = "_codVrsVdi", required = true)
    protected String codVrsVdi;
    @XmlElement(name = "_codRgi", required = true)
    protected String codRgi;
    @XmlElement(name = "_codStu", required = true)
    protected String codStu;
    @XmlElement(name = "_libCmtLpa", required = true)
    protected String libCmtLpa;
    @XmlElement(name = "_codCatOuiSi", required = true)
    protected String codCatOuiSi;
    @XmlElement(name = "_mtfCat", required = true)
    protected String mtfCat;
    @XmlElement(name = "_codCatExoExt", required = true)
    protected String codCatExoExt;

    /**
     * Obtient la valeur de la propriété typLpa.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTypLpa() {
        return typLpa;
    }

    /**
     * Définit la valeur de la propriété typLpa.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTypLpa(String value) {
        this.typLpa = value;
    }

    /**
     * Obtient la valeur de la propriété codAnu.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodAnu() {
        return codAnu;
    }

    /**
     * Définit la valeur de la propriété codAnu.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodAnu(String value) {
        this.codAnu = value;
    }

    /**
     * Obtient la valeur de la propriété numOPI.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getNumOPI() {
        return numOPI;
    }

    /**
     * Définit la valeur de la propriété numOPI.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setNumOPI(String value) {
        this.numOPI = value;
    }

    /**
     * Obtient la valeur de la propriété codEtu.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodEtu() {
        return codEtu;
    }

    /**
     * Définit la valeur de la propriété codEtu.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodEtu(String value) {
        this.codEtu = value;
    }

    /**
     * Obtient la valeur de la propriété codEtp.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodEtp() {
        return codEtp;
    }

    /**
     * Définit la valeur de la propriété codEtp.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodEtp(String value) {
        this.codEtp = value;
    }

    /**
     * Obtient la valeur de la propriété codVrsVet.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodVrsVet() {
        return codVrsVet;
    }

    /**
     * Définit la valeur de la propriété codVrsVet.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodVrsVet(String value) {
        this.codVrsVet = value;
    }

    /**
     * Obtient la valeur de la propriété codDip.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodDip() {
        return codDip;
    }

    /**
     * Définit la valeur de la propriété codDip.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodDip(String value) {
        this.codDip = value;
    }

    /**
     * Obtient la valeur de la propriété codVrsVdi.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodVrsVdi() {
        return codVrsVdi;
    }

    /**
     * Définit la valeur de la propriété codVrsVdi.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodVrsVdi(String value) {
        this.codVrsVdi = value;
    }

    /**
     * Obtient la valeur de la propriété codRgi.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodRgi() {
        return codRgi;
    }

    /**
     * Définit la valeur de la propriété codRgi.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodRgi(String value) {
        this.codRgi = value;
    }

    /**
     * Obtient la valeur de la propriété codStu.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodStu() {
        return codStu;
    }

    /**
     * Définit la valeur de la propriété codStu.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodStu(String value) {
        this.codStu = value;
    }

    /**
     * Obtient la valeur de la propriété libCmtLpa.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLibCmtLpa() {
        return libCmtLpa;
    }

    /**
     * Définit la valeur de la propriété libCmtLpa.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLibCmtLpa(String value) {
        this.libCmtLpa = value;
    }

    /**
     * Obtient la valeur de la propriété codCatOuiSi.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodCatOuiSi() {
        return codCatOuiSi;
    }

    /**
     * Définit la valeur de la propriété codCatOuiSi.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodCatOuiSi(String value) {
        this.codCatOuiSi = value;
    }

    /**
     * Obtient la valeur de la propriété mtfCat.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMtfCat() {
        return mtfCat;
    }

    /**
     * Définit la valeur de la propriété mtfCat.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMtfCat(String value) {
        this.mtfCat = value;
    }

    /**
     * Obtient la valeur de la propriété codCatExoExt.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodCatExoExt() {
        return codCatExoExt;
    }

    /**
     * Définit la valeur de la propriété codCatExoExt.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodCatExoExt(String value) {
        this.codCatExoExt = value;
    }

}

==> apo-ws-client-6.00.51.4-sources.jar: fr/univlorraine/apowsclient/laissezPasser/MettreAJourLaissezPasserWSV2.java <==

package fr.univlorraine.apowsclient.laissezPasser;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="typLpa" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="codAnu" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="numOPI" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="codEtu" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="codEtp" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="codVrsVet" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="codDip" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="codVrsVdi" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="codRgi" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="codStu" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="libCmtLpa" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="codCatOuiSi" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="mtfCat" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="codCatExoExt" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "typLpa",
    "codAnu",
    "numOPI",
    "codEtu",
    "codEtp",
    "codVrsVet",
    "codDip",
    "codVrsVdi",
    "codRgi",
    "codStu",
    "libCmtLpa",
    "codCatOuiSi",
    "mtfCat",
    "codCatExoExt"
})
@XmlRootElement(name = "mettreAJourLaissezPasserWS_V2")
public class MettreAJourLaissezPasserWSV2 {

    @XmlElement(required = true)
    protected String typLpa;
    @XmlElement(required = true)
    protected String codAnu;
    @XmlElement(required = true)
    protected String numOPI;
    @XmlElement(required = true)
    protected String codEtu;
    @XmlElement(required = true)
    protected String codEtp;
    @XmlElement(required = true)
    protected String codVrsVet;
    @XmlElement(required = true)
    protected String codDip;
    @XmlElement(required = true)
    protected String codVrsVdi;
    @XmlElement(required = true)
    protected String codRgi;
    @XmlElement(required = true)
    protected String codStu;
    @XmlElement(required = true)
    protected String libCmtLpa;
    @XmlElement(required = true)
    protected String codCatOuiSi;
    @XmlElement(required = true)
    protected String mtfCat;
    @XmlElement(required = true)
    protected String codCatExoExt;

    /**
     * Obtient la valeur de la propriété typLpa.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTypLpa() {
        return typLpa;
    }

    /**
     * Définit la valeur de la propriété typLpa.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTypLpa(String value) {
        this.typLpa = value;
    }

    /**
     * Obtient la valeur de la propriété codAnu.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodAnu() {
        return codAnu;
    }

    /**
     * Définit la valeur de la propriété codAnu.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodAnu(String value) {
        this.codAnu = value;
    }

    /**
     * Obtient la valeur de la propriété numOPI.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getNumOPI() {
        return numOPI;
    }

    /**
     * Définit la valeur de la propriété numOPI.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setNumOPI(String value) {
        this.numOPI = value;
    }

    /**
     * Obtient la valeur de la propriété codEtu.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodEtu() {
        return codEtu;
    }

    /**
     * Définit la valeur de la propriété codEtu.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodEtu(String value) {
        this.codEtu = value;
    }

    /**
     * Obtient la valeur de la propriété codEtp.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodEtp() {
        return codEtp;
    }

    /**
     * Définit la valeur de la propriété codEtp.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodEtp(String value) {
        this.codEtp = value;
    }

    /**
     * Obtient la valeur de la propriété codVrsVet.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodVrsVet() {
        return codVrsVet;
    }

    /**
     * Définit la valeur de la propriété codVrsVet.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodVrsVet(String value) {
        this.codVrsVet = value;
    }

    /**
     * Obtient la valeur de la propriété codDip.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodDip() {
        return codDip;
    }

    /**
     * Définit la valeur de la propriété codDip.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodDip(String value) {
        this.codDip = value;
    }

    /**
     * Obtient la valeur de la propriété codVrsVdi.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodVrsVdi() {
        return codVrsVdi;
    }

    /**
     * Définit la valeur de la propriété codVrsVdi.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodVrsVdi(String value) {
        this.codVrsVdi = value;
    }

    /**
     * Obtient la valeur de la propriété codRgi.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodRgi() {
        return codRgi;
    }

    /**
     * Définit la valeur de la propriété codRgi.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodRgi(String value) {
        this.codRgi = value;
    }

    /**
     * Obtient la valeur de la propriété codStu.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodStu() {
        return codStu;
    }

    /**
     * Définit la valeur de la propriété codStu.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodStu(String value) {
        this.codStu = value;
    }

    /**
     * Obtient la valeur de la propriété libCmtLpa.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLibCmtLpa() {
        return libCmtLpa;
    }

    /**
     * Définit la valeur de la propriété libCmtLpa.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLibCmtLpa(String value) {
        this.libCmtLpa = value;
    }

    /**
     * Obtient la valeur de la propriété codCatOuiSi.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodCatOuiSi() {
        return codCatOuiSi;
    }

    /**
     * Définit la valeur de la propriété codCatOuiSi.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodCatOuiSi(String value) {
        this.codCatOuiSi = value;
    }

    /**
     * Obtient la valeur de la propriété mtfCat.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMtfCat() {
        return mtfCat;
    }

    /**
     * Définit la valeur de la propriété mtfCat.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMtfCat(String value) {
        this.mtfCat = value;
    }

    /**
     * Obtient la valeur de la propriété codCatExoExt.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodCatExoExt() {
        return codCatExoExt;
    }

    /**
     * Définit la valeur de la propriété codCatExoExt.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodCatExoExt(String value) {
        this.codCatExoExt = value;
    }

}
